@@ -49,7 +49,6 @@
 #include <KLocalizedString>
 #include <KMime/Content>
 #include <KMime/Message>
-#include <kidentitymanagement/identitymanager.h>
 #include <KSystemTimeZones>
 
 #include <QtCore/QFileInfo>
@@ -241,7 +240,7 @@ InvitationsAgent::InvitationsAgent(const QString &id)
     //changeRecorder()->setCollectionMonitored( Collection::root(), true );
 
     connect(this, &InvitationsAgent::reloadConfiguration, this, &InvitationsAgent::initStart);
-    QTimer::singleShot(0, this, SLOT(initStart()));
+    QTimer::singleShot(0, this, &InvitationsAgent::initStart);
 }
 
 InvitationsAgent::~InvitationsAgent()
@@ -481,7 +480,7 @@ Item InvitationsAgent::handleContent(const QString &vcal,
     Q_ASSERT(incidence);
 
     IncidenceAttribute *attr = new IncidenceAttribute;
-    attr->setStatus(QLatin1String("new"));   //TODO
+    attr->setStatus(QStringLiteral("new"));   //TODO
     //attr->setFrom( message->from()->asUnicodeString() );
     attr->setReference(item.id());
 
