@@ -227,7 +227,11 @@ void NewMailNotifierAgent::setShowButtonToDisplayMail(bool b)
 
 void NewMailNotifierAgent::showConfigureDialog(qlonglong windowId)
 {
-    configure(windowId);
+#ifndef Q_OS_WIN
+    configure(static_cast<WId>(windowId));
+#else
+    configure(reinterpret_cast<WId>(windowId));
+#endif
 }
 
 void NewMailNotifierAgent::configure(WId windowId)
@@ -299,6 +303,8 @@ void NewMailNotifierAgent::itemsRemoved(const Item::List &items)
 
 void NewMailNotifierAgent::itemsFlagsChanged(const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
 {
+    Q_UNUSED(removedFlags);
+
     if (!isActive()) {
         return;
     }
@@ -572,4 +578,3 @@ bool NewMailNotifierAgent::isActive() const
 }
 
 AKONADI_AGENT_MAIN(NewMailNotifierAgent)
-
