@@ -25,7 +25,6 @@
 #include <QModelIndex>
 #include <QIdentityProxyModel>
 
-class QItemSelectionModel;
 class KRecursiveFilterProxyModel;
 namespace Akonadi
 {
@@ -61,18 +60,15 @@ public:
 
     void updateCollectionsRecursive();
 
-private Q_SLOTS:
+private:
     void slotSelectAllCollections();
     void slotUnselectAllCollections();
     void slotModifyJobDone(KJob *job);
     void slotSetCollectionFilter(const QString &);
 
     void slotCollectionTreeFetched();
-
-private:
     void forceStatus(const QModelIndex &parent, bool status);
     QTreeView *mFolderView;
-    QItemSelectionModel *mSelectionModel;
     Akonadi::EntityTreeModel *mModel;
     Akonadi::ChangeRecorder *mChangeRecorder;
     KRecursiveFilterProxyModel *mCollectionFilter;
