@@ -21,6 +21,7 @@
 #include "davmanager.h"
 #include "davprotocolbase.h"
 #include "davutils.h"
+#include "etagcache.h"
 
 #include <kio/davjob.h>
 #include <kio/job.h>
@@ -28,8 +29,8 @@
 
 #include <QtCore/QBuffer>
 
-DavItemsListJob::DavItemsListJob(const DavUtils::DavUrl &url, QObject *parent)
-    : KJob(parent), mUrl(url), mSubJobCount(0)
+DavItemsListJob::DavItemsListJob(const DavUtils::DavUrl &url, const EtagCache *cache, QObject *parent)
+    : KJob(parent), mUrl(url), mEtagCache(cache), mSubJobCount(0)
 {
 }
 
@@ -38,16 +39,29 @@ void DavItemsListJob::setContentMimeTypes(const QStringList &types)
     mMimeTypes = types;
 }
 
+void DavItemsListJob::setTimeRange(const QString &start, const QString &end)
+{
+    mRangeStart = start;
+    mRangeEnd = end;
+}
+
 void DavItemsListJob::start()
 {
     const DavProtocolBase *protocol = DavManager::self()->davProtocol(mUrl.protocol());
     Q_ASSERT(protocol);
-    QVectorIterator<QDomDocument> it(protocol->itemsQueries());
-    int queryIndex = 0;
+    QVectorIterator<XMLQueryBuilder::Ptr> it(protocol->itemsQueries());
 
     while (it.hasNext()) {
-        const QDomDocument props = it.next();
-        const QString mimeType = protocol->mimeTypeForQuery(queryIndex);
+        XMLQueryBuilder::Ptr builder = it.next();
+        if (!mRangeStart.isEmpty()) {
+            builder->setParameter(QStringLiteral("start"), mRangeStart);
+        }
+        if (!mRangeEnd.isEmpty()) {
+            builder->setParameter(QStringLiteral("end"), mRangeEnd);
+        }
+
+        const QDomDocument props = builder->buildQuery();
+        const QString mimeType = builder->mimeType();
 
         if (mMimeTypes.isEmpty() || mMimeTypes.contains(mimeType)) {
             ++mSubJobCount;
@@ -65,8 +79,6 @@ void DavItemsListJob::start()
                 connect(job, &KIO::DavJob::result, this, &DavItemsListJob::davJobFinished);
             }
         }
-
-        ++queryIndex;
     }
 }
 
@@ -75,6 +87,16 @@ DavItem::List DavItemsListJob::items() const
     return mItems;
 }
 
+DavItem::List DavItemsListJob::changedItems() const
+{
+    return mChangedItems;
+}
+
+QStringList DavItemsListJob::deletedItems() const
+{
+    return mDeletedItems;
+}
+
 void DavItemsListJob::davJobFinished(KJob *job)
 {
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
@@ -166,18 +188,17 @@ void DavItemsListJob::davJobFinished(KJob *job)
             const QDomElement hrefElement = DavUtils::firstChildElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("href"));
             const QString href = hrefElement.text();
 
-            KUrl url = davJob->url();
-            url.setUser(QString());
+            QUrl url = davJob->url();
+            url.setUserInfo(QString());
             if (href.startsWith(QLatin1Char('/'))) {
                 // href is only a path, use request url to complete
-                url.setPath(QUrl::fromPercentEncoding(href.toLatin1()));
+                url.setPath(href, QUrl::TolerantMode);
             } else {
                 // href is a complete url
-                KUrl tmpUrl(href);
-                url = tmpUrl;
+                url = QUrl::fromUserInput(href);
             }
 
-            QString itemUrl = url.prettyUrl();
+            QString itemUrl = url.toDisplayString();
             if (mSeenUrls.contains(itemUrl)) {
                 responseElement = DavUtils::nextSiblingElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("response"));
                 continue;
@@ -193,10 +214,18 @@ void DavItemsListJob::davJobFinished(KJob *job)
 
             mItems << item;
 
+            if (mEtagCache->etagChanged(itemUrl, item.etag())) {
+                mChangedItems << item;
+            }
+
             responseElement = DavUtils::nextSiblingElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("response"));
         }
     }
 
+    QSet<QString> removed = mEtagCache->urls().toSet();
+    removed.subtract(mSeenUrls);
+    mDeletedItems = removed.toList();
+
     if (--mSubJobCount == 0) {
         emitResult();
     }
