@@ -20,13 +20,13 @@
 
 #include "serverinfodialog.h"
 #include "imapresource.h"
-#include "ui_serverinfo.h"
 
 #include <KLocalizedString>
 #include <QDialogButtonBox>
 #include <KConfigGroup>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QPainter>
 
 ServerInfoDialog::ServerInfoDialog(ImapResourceBase *parentResource, QWidget *parent)
     : QDialog(parent)
@@ -37,21 +37,48 @@ ServerInfoDialog::ServerInfoDialog(ImapResourceBase *parentResource, QWidget *pa
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
-    QWidget *w = new QWidget;
-    mainLayout->addWidget(w);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ServerInfoDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerInfoDialog::reject);
     setAttribute(Qt::WA_DeleteOnClose);
 
-    mServerInfoWidget = new Ui::ServerInfo();
-    mServerInfoWidget->setupUi(w);
+    mTextBrowser = new ServerInfoTextBrowser(this);
+    mainLayout->addWidget(mTextBrowser);
     mainLayout->addWidget(buttonBox);
-    mServerInfoWidget->serverInfo->setPlainText(
-        parentResource->serverCapabilities().join(QStringLiteral("\n")));
+    mTextBrowser->setPlainText(parentResource->serverCapabilities().join(QStringLiteral("\n")));
 }
 
 ServerInfoDialog::~ServerInfoDialog()
 {
-    delete mServerInfoWidget;
+}
+
+
+ServerInfoTextBrowser::ServerInfoTextBrowser(QWidget *parent)
+    : QTextBrowser(parent)
+{
+}
+
+ServerInfoTextBrowser::~ServerInfoTextBrowser()
+{
+
+}
+
+void ServerInfoTextBrowser::paintEvent(QPaintEvent *event)
+{
+    if (toPlainText().isEmpty()) {
+        QPainter p(viewport());
+
+        QFont font = p.font();
+        font.setItalic(true);
+        p.setFont(font);
+
+        const QPalette palette = viewport()->palette();
+        QColor color = palette.text().color();
+        color.setAlpha(128);
+        p.setPen(color);
+
+        p.drawText(QRect(0, 0, width(), height()), Qt::AlignCenter, i18n("Resource not synchronized yet."));
+    } else {
+        QTextBrowser::paintEvent(event);
+    }
 }
 
