@@ -22,12 +22,19 @@
 #define SERVERINFODIALOG_H
 
 #include <QDialog>
-
+#include <QTextBrowser>
 class ImapResourceBase;
-namespace Ui
+
+
+class ServerInfoTextBrowser : public QTextBrowser
 {
-class ServerInfo;
-}
+    Q_OBJECT
+public:
+    explicit ServerInfoTextBrowser(QWidget *parent = Q_NULLPTR);
+    ~ServerInfoTextBrowser();
+protected:
+    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+};
 
 class ServerInfoDialog : public QDialog
 {
@@ -36,7 +43,7 @@ public:
     explicit ServerInfoDialog(ImapResourceBase *parentResource, QWidget *parent);
     ~ServerInfoDialog();
 private:
-    Ui::ServerInfo *mServerInfoWidget;
+    ServerInfoTextBrowser *mTextBrowser;
 };
 
 #endif // SERVERINFODIALOG_H
