@@ -28,10 +28,10 @@ class KolabChangeItemsRelationsTask : public KolabRelationResourceTask
 {
     Q_OBJECT
 public:
-    explicit KolabChangeItemsRelationsTask(ResourceStateInterface::Ptr resource, QObject *parent = Q_NULLPTR);
+    explicit KolabChangeItemsRelationsTask(const ResourceStateInterface::Ptr &resource, QObject *parent = Q_NULLPTR);
 
 protected:
-    virtual void startRelationTask(KIMAP::Session *session);
+    void startRelationTask(KIMAP::Session *session) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void onRelationFetchDone(KJob *job);
